@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.027-4-gf850eba
+package Dist::Zilla::Plugin::DynamicPrereqs; # git description: v0.028-4-g655ac72
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 # ABSTRACT: Specify dynamic (user-side) prerequisites for your distribution
 # KEYWORDS: plugin distribution metadata MYMETA prerequisites Makefile.PL dynamic
 
-our $VERSION = '0.028';
+our $VERSION = '0.029';
 
 use Moose;
 with
@@ -65,6 +65,11 @@ has $_ => (
     default => sub { [] },
 ) foreach qw(include_subs conditions);
 
+# temporary workaround for broken Module::CoreList::is_core
+has '+include_dependencies' => (
+    default => 0,
+) if eval { Dist::Zilla::Role::ModuleIncluder->VERSION('0.005'); 1 };
+
 sub mvp_multivalue_args { qw(raw include_subs conditions) }
 
 sub mvp_aliases { +{
@@ -404,7 +409,7 @@ Dist::Zilla::Plugin::DynamicPrereqs - Specify dynamic (user-side) prerequisites
 
 =head1 VERSION
 
-version 0.028
+version 0.029
 
 =head1 SYNOPSIS
 
